import { deepMerge } from '@copyfrom/deep-merge';
import { defineNuxtModule, createResolver, addImports } from '@nuxt/kit';

const name = "@copyfrom/nuxt-http";
const version = "1.0.3";
const author = {
	name: "devcui",
	email: "devcui@outlook.com"
};
const description = "nuxt http module";
const repository = {
	type: "git",
	url: "https://github.com/copyfrom/nuxt-http.git"
};
const license = "Apache-2.0";
const type = "module";
const scripts = {
	"dev:prepare": "esno --tsconfig=./tsconfig.esno.json ./scripts/prepare.ts",
	build: "esno --tsconfig=./tsconfig.json ./scripts/build",
	dev: "nuxt dev playground",
	lint: "eslint .",
	"lint:fix": "eslint . --fix",
	coverage: "vitest run --coverage",
	test: "vitest run",
	"test:watch": "vitest watch",
	"test:types": "vue-tsc --noEmit && cd playground && vue-tsc --noEmit"
};
const dependencies = {
	"@copyfrom/deep-merge": "^1.0.5",
	"@nuxt/kit": "^3.11.2"
};
const devDependencies = {
	"@vitest/coverage-v8": "^1.6.0",
	"@nuxt/devtools": "^1.2.0",
	"@nuxt/eslint-config": "^0.3.10",
	"@nuxt/module-builder": "^0.6.0",
	"@nuxt/schema": "^3.11.2",
	"@nuxt/test-utils": "^3.12.1",
	"@types/node": "^20.12.11",
	changelogen: "^0.5.5",
	eslint: "^9.2.0",
	esno: "^4.7.0",
	nuxt: "^3.11.2",
	typescript: "latest",
	unbuild: "^2.0.0",
	vitest: "^1.6.0",
	"vue-tsc": "^2.0.16"
};
const packageJSON = {
	name: name,
	version: version,
	author: author,
	description: description,
	repository: repository,
	license: license,
	type: type,
	scripts: scripts,
	dependencies: dependencies,
	devDependencies: devDependencies
};

const DefaultModuleOptions = {
  baseURL: "/"
};
const module = defineNuxtModule({
  meta: { name: packageJSON.name, configKey: "http" },
  defaults: DefaultModuleOptions,
  setup(options, nuxt) {
    options = deepMerge(DefaultModuleOptions, options);
    nuxt.options.runtimeConfig.public.http = options;
    const { resolve } = createResolver(import.meta.url);
    nuxt.options.build.transpile.push(resolve("./runtime"));
    addImports({ name: "useHttp", as: "useHttp", from: resolve("./runtime/composables") });
  }
});

export { DefaultModuleOptions, module as default };
